from django.http import HttpResponseBadRequest, HttpResponseForbidden, HttpResponseNotAllowed, HttpResponseNotFound, HttpResponseServerError
from django.shortcuts import redirect
from django.utils import translation
from django.views.generic.base import View
from django.views.generic import TemplateView, ListView
from django.views import View
from django.shortcuts import render
from django.views.generic.list import QuerySet
from django.db.models import Q
from django.views.static import loader
from django.views import i18n
from requests import request

from .models import Link

from abc import ABC

import logging
logger = logging.getLogger(__name__)


class Index(TemplateView):
    """
    The index page of the gawa app.

    Utilizes a generic view, because I will do so for all views,
    a regular view function would suffice.
    """

    template_name: str = "start/index.html"


class Professional(TemplateView):
    """
    Professional informations that might interest a professional employer
    """
    # TODO
    template_name: str = "start/legalinfo.html"


class Reporting(TemplateView):
    """
    Reporting Interface and information about the allowed scope of searching for
    security issues.
    """
    # TODO
    template_name: str = "start/reporting.html"


class LegalInfo(TemplateView):
    """
    Legal info that the german authorities want.
    """
    # TODO
    template_name: str = "start/legalinfo.html"


class Links(ListView):
    """
    This View contains links to various interesting sites.
    """
    model = Link
    context_object_name = "links"
    template_name = "start/links.html"

    def get_queryset(self) -> QuerySet:
        object_list = Link.objects.filter(
            public=True, personal=False
        )
        return object_list

    def get_queryset_personal_links(self) -> QuerySet:
        object_list = Link.objects.filter(
            public=True, personal=True
        )
        return object_list

    def get_context_data(self, *, object_list=None, **kwargs):
        context = super().get_context_data(object_list=object_list, **kwargs)
        context['personal_links'] = self.get_queryset_personal_links()
        return context
